@@ -36,4 +36,10 @@ class TestSystem(unittest.TestCase):
         available = system.networks_available()
         print(available)
         networks_up = [net for net in available if system.network_is_up(net)]
-        self.assertGreaterEqual(len(networks_up), 0)
\ No newline at end of file
+        self.assertGreaterEqual(len(networks_up), 0)
+
+    def test_unknown_network_status(self):
+        self.assertFalse((System()).network_is_up('_unknown_'))
+
+    def test_no_networks_available(self):
+        self.assertListEqual((System('/sys/class/no_net')).networks_available(), [])
\ No newline at end of file
